        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260726 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260726 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 26 <strong>control</strong><br>0,2,3,7,8,10,12,13,15,18,20,21,24,27,28,29,30,32,34,36,39,40,41,42,43,49';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260726 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>31</strong> miembros: 25 <br>1,4,5,6,9,11,14,16,17,19,22,23,25,26,31,33,35,37,38,44,45,46,47,48,50';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260726 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260726 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 26 <strong>control</strong><br>0,2,3,7,8,10,12,13,15,18,20,21,24,27,28,29,30,32,34,36,39,40,41,42,43,49';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260726 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>31</strong> miembros: 25 <br>1,4,5,6,9,11,14,16,17,19,22,23,25,26,31,33,35,37,38,44,45,46,47,48,50';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260726 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260726 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 26 <strong>control</strong><br>0,2,3,7,8,10,12,13,15,18,20,21,24,27,28,29,30,32,34,36,39,40,41,42,43,49';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260726 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>31</strong> miembros: 25 <br>1,4,5,6,9,11,14,16,17,19,22,23,25,26,31,33,35,37,38,44,45,46,47,48,50';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260726 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260726 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 26 <strong>control</strong><br>0,2,3,7,8,10,12,13,15,18,20,21,24,27,28,29,30,32,34,36,39,40,41,42,43,49';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260726 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>31</strong> miembros: 25 <br>1,4,5,6,9,11,14,16,17,19,22,23,25,26,31,33,35,37,38,44,45,46,47,48,50';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260726 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260726 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 26 <strong>control</strong><br>0,2,3,7,8,10,12,13,15,18,20,21,24,27,28,29,30,32,34,36,39,40,41,42,43,49';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260726 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>31</strong> miembros: 25 <br>1,4,5,6,9,11,14,16,17,19,22,23,25,26,31,33,35,37,38,44,45,46,47,48,50';}
}
